==> gshisen-0.2.tar.gz: GShisen/gshisen.m <==
#include "gshisen.h"

int catchXError(Display *dpy, XErrorEvent *error)
{
    return 0;
}

static GShisen *sharedshisen = nil;

@implementation GShisen

+ (GShisen *)sharedshisen
{
    if(!sharedshisen) {
        NS_DURING
            {
                [gnustep_global_lock lock];
                sharedshisen = [[self alloc] init];
                [gnustep_global_lock unlock];
            }
        NS_HANDLER
            {
                [gnustep_global_lock unlock];
                [localException raise];
            }
        NS_ENDHANDLER
            }
    return sharedshisen;
}

- (void)dealloc
{
    [board release];
    [win release];
    [super dealloc];
}

- (void)applicationDidFinishLaunching:(NSNotification *)aNotification
{
    unsigned int style = NSTitledWindowMask | NSClosableWindowMask	| NSMiniaturizableWindowMask;

    XSetErrorHandler((XErrorHandler)catchXError);
	
    win = [[NSWindow alloc] initWithContentRect: NSMakeRect(0, 0, 740, 490)
                            styleMask: style
                            backing: NSBackingStoreRetained
                            defer: NO];
    [win setMaxSize: NSMakeSize(740, 520)];
    [win setMinSize: NSMakeSize(740, 490)];
    [win setTitle: @"GShisen"];
    board = [[GSBoard alloc] initWithFrame: NSMakeRect(0, 0, 740, 490)];
    [win setContentView: board];
    [win center];
    [win display];
    [win orderFront:nil];
}

- (BOOL)applicationShouldTerminate:(NSApplication *)app 
{
    return YES;
}

- (void)newGame:(id)sender
{
    [board newGame];
}

- (void)undo:(id)sender
{
    [board undo];
}

- (void)getHint:(id)sender
{
    [board getHint];
}

- (void)method:menuCell
{

}

- (void)runInfoPanel:(id)sender
{
  NSMutableDictionary *d;

  d = AUTORELEASE ([NSMutableDictionary new]);
  [d setObject: @"GShisen" forKey: @"ApplicationName"];
  [d setObject: @"The first GNUstep Game!" 
     forKey: @"ApplicationDescription"];
  [d setObject: @"GShisen 0.2" forKey: @"ApplicationRelease"];
  [d setObject: @"Apr 2000" forKey: @"FullVersionID"];
  [d setObject: [NSArray arrayWithObjects: 
			   @"James Dessart <skwirl@cam.org>",
				@" Enrico Sersale <enrico@imago.ro>", nil]
     forKey: @"Authors"];
  [d setObject: @"See http://www.imago.ro/gshisen" forKey: @"URL"];
  [d setObject: @"Copyright (C) 1999, 2000 Free Software Foundation, Inc."
     forKey: @"Copyright"];
  [d setObject: @"Released under the GNU General Public License 2.0"
     forKey: @"CopyrightDescription"];
  
  [NSApp orderFrontStandardInfoPanelWithOptions:d];
}

@end

==> gshisen-1.1.tar.gz: GShisen/gshisen.m <==
#include "gshisen.h"

static GShisen *sharedshisen = nil;

@implementation GShisen

+ (GShisen *)sharedshisen
{
    if(!sharedshisen) {
        NS_DURING
            {
                sharedshisen = [[self alloc] init];
            }
        NS_HANDLER
            {
                [localException raise];
            }
        NS_ENDHANDLER
            }
    return sharedshisen;
}

- (void)dealloc
{
    [board release];
    [win release];
    [super dealloc];
}

- (void)applicationDidFinishLaunching:(NSNotification *)aNotification
{
    unsigned int style = NSTitledWindowMask | NSClosableWindowMask	| NSMiniaturizableWindowMask;

    win = [[NSWindow alloc] initWithContentRect: NSMakeRect(0, 0, 740, 490)
                            styleMask: style
                            backing: NSBackingStoreBuffered
                            defer: NO];
    [win setMaxSize: NSMakeSize(740, 520)];
    [win setMinSize: NSMakeSize(740, 490)];
    [win setTitle: @"GShisen"];
    board = [[GSBoard alloc] initWithFrame: NSMakeRect(0, 0, 740, 490)];
    [win setContentView: board];
    [win center];
    [win display];
    [win orderFront:nil];
}

- (BOOL)applicationShouldTerminate:(NSApplication *)app 
{
    return YES;
}

- (void)newGame:(id)sender
{
    [board newGame];
}

- (void)pause:(id)sender
{
    [board pause];
}

- (void)undo:(id)sender
{
    [board undo];
}

- (void)getHint:(id)sender
{
    [board getHint];
}

- (void)runInfoPanel:(id)sender
{
  NSMutableDictionary *d;

  d = [NSMutableDictionary new];
  [d setObject: @"GShisen" forKey: @"ApplicationName"];
  [d setObject: @"The first GNUstep Game!" 
     forKey: @"ApplicationDescription"];
  [d setObject: @"GShisen 1.1" forKey: @"ApplicationRelease"];
  [d setObject: @"Jan 2002" forKey: @"FullVersionID"];
  [d setObject: [NSArray arrayWithObjects: 
			   @"James Dessart <james@skwirl.ca>",
				@" Enrico Sersale <enrico@imago.ro>", nil]
     forKey: @"Authors"];
  [d setObject: @"See http://www.imago.ro/gshisen" forKey: @"URL"];
  [d setObject: @"Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc."
     forKey: @"Copyright"];
  [d setObject: @"Released under the GNU General Public License 2.0"
     forKey: @"CopyrightDescription"];
  
#ifdef GNUSTEP	
  [NSApp orderFrontStandardInfoPanelWithOptions: d];
#else
	[NSApp orderFrontStandardAboutPanel: d];
#endif
}

@end
